@@ -1,3 +1,7 @@
+from dataclasses import dataclass
+
+
+@dataclass
 class Map:
     uuid: str
     display_name: str
@@ -27,6 +31,3 @@ class Map:
         self.x_scalar_to_add = data.get("xScalarToAdd")
         self.y_scalar_to_add = data.get("yScalarToAdd")
         self.raw_data = data
-
-    def __str__(self):
-        return str(self.raw_data)
